@@ -1702,6 +1702,8 @@ BotClass <- R6::R6Class("Bot",
     send_message = sendMessage,
     deleteMessage = deleteMessage,
     delete_message = deleteMessage,
+    forwardMessage = forwardMessage,
+    forward_message = forwardMessage,
     sendPhoto = sendPhoto,
     send_photo = sendPhoto,
     sendAudio = sendAudio,
